#[non_exhaustive]pub enum BinstallError {
Show 31 variants
TaskJoinError(JoinError),
UserAbort,
InvalidSignature {
crate_name: CompactString,
package_name: CompactString,
},
MissingSignature(CompactString),
UrlParse(ParseError),
TemplateParseError(ParseError),
FetchError(Box<FetchError>),
Download(DownloadError),
SubProcess {
command: Box<str>,
status: ExitStatus,
},
Io(Error),
UnknownRegistryName(CompactString),
RegistryError(Box<RegistryError>),
CargoManifestPath,
CargoManifest(Box<Error>),
RegistryParseError(Box<InvalidRegistryError>),
VersionParse(Box<VersionParseError>),
SuperfluousVersionOption,
UnspecifiedBinaries,
NoViableTargets,
BinFile(Error),
CargoTomlMissingPackage(CompactString),
DuplicateSourceFilePath {
path: PathBuf,
},
NoFallbackToCargoInstall,
InvalidPkgFmt(Box<InvalidPkgFmtError>),
GhApiErr(Box<GhApiError>),
TargetTripleParseError(Box<TargetTripleParseError>),
GitError(GitError),
LoadManifestFromWSError(Box<Error>),
CargoInstallDoesNotSupportInstallPath,
CrateContext(Box<CrateContextError>),
Errors(CrateErrors),
}Expand description
Error kinds emitted by cargo-binstall.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
TaskJoinError(JoinError)
Internal: a task could not be joined.
- Code:
binstall::internal::task_join - Exit: 17
UserAbort
The installation was cancelled by a user at a confirmation prompt,
or user send a ctrl_c on all platforms or
SIGINT, SIGHUP, SIGTERM or SIGQUIT on unix to the program.
- Code:
binstall::user_abort - Exit: 32
InvalidSignature
Package is not signed and policy requires it.
- Code:
binstall::signature::invalid - Exit: 40
MissingSignature(CompactString)
Package is not signed and policy requires it.
- Code:
binstall::signature::missing - Exit: 41
UrlParse(ParseError)
A URL is invalid.
This may be the result of a template in a Cargo manifest.
- Code:
binstall::url_parse - Exit: 65
TemplateParseError(ParseError)
Failed to parse template.
- Code:
binstall::template - Exit: 67
FetchError(Box<FetchError>)
Failed to fetch pre-built binaries.
- Code:
binstall::fetch - Exit: 68
Download(DownloadError)
Failed to download or failed to decode the body.
- Code:
binstall::download - Exit: 68
SubProcess
A subprocess failed.
This is often about cargo-install calls.
- Code:
binstall::subprocess - Exit: 70
Io(Error)
A generic I/O error.
- Code:
binstall::io - Exit: 74
UnknownRegistryName(CompactString)
Unknown registry name
- Code:
binstall::cargo_registry - Exit: 75
RegistryError(Box<RegistryError>)
An error interacting with the crates.io API.
This could either be a “not found” or a server/transport error.
- Code:
binstall::cargo_registry - Exit: 76
CargoManifestPath
The override path to the cargo manifest is invalid or cannot be resolved.
- Code:
binstall::cargo_manifest_path - Exit: 77
CargoManifest(Box<Error>)
A parsing or validation error in a cargo manifest.
This should be rare, as manifests are generally fetched from crates.io, which does its own
validation upstream. The most common failure will therefore be for direct repository access
and with the --manifest-path option.
- Code:
binstall::cargo_manifest - Exit: 78
RegistryParseError(Box<InvalidRegistryError>)
Failure to parse registry index url
- Code:
binstall::cargo_registry - Exit: 79
VersionParse(Box<VersionParseError>)
A version is not valid semver.
Note that we use the semver crate, which parses Cargo version syntax; this may be
somewhat stricter or very slightly different from other semver implementations.
- Code:
binstall::version::parse - Exit: 80
SuperfluousVersionOption
The crate@version syntax was used at the same time as the –version option.
You can’t do that as it’s ambiguous which should apply.
- Code:
binstall::conflict::version - Exit: 84
UnspecifiedBinaries
No binaries were found for the crate.
When installing, either the binaries are specified in the crate’s Cargo.toml, or they’re inferred from the crate layout (e.g. src/main.rs or src/bins/name.rs). If no binaries are found through these methods, we can’t know what to install!
- Code:
binstall::resolve::binaries - Exit: 86
NoViableTargets
No viable targets were found.
When installing, we attempt to find which targets the host (your computer) supports, and discover builds for these targets from the remote binary source. This error occurs when we fail to discover the host’s target.
You should in this case specify –target manually.
- Code:
binstall::targets::none_host - Exit: 87
BinFile(Error)
Failed to find or install binaries.
- Code:
binstall::bins - Exit: 88
CargoTomlMissingPackage(CompactString)
Cargo.toml of the crate does not have section “Package”.
- Code:
binstall::cargo_manifest - Exit: 89
DuplicateSourceFilePath
bin-dir configuration provided generates duplicate source path.
- Code:
binstall::cargo_manifest - Exit: 90
NoFallbackToCargoInstall
Fallback to cargo-install is disabled.
- Code:
binstall::no_fallback_to_cargo_install - Exit: 94
InvalidPkgFmt(Box<InvalidPkgFmtError>)
Fallback to cargo-install is disabled.
- Code:
binstall::invalid_pkg_fmt - Exit: 95
GhApiErr(Box<GhApiError>)
Request to GitHub API failed
- Code:
binstall::gh_api_failure - Exit: 96
TargetTripleParseError(Box<TargetTripleParseError>)
Failed to parse target triple
- Code:
binstall::target_triple_parse_error - Exit: 97
GitError(GitError)
git only.Failed to shallow clone git repository
- Code:
binstall::git - Exit: 98
LoadManifestFromWSError(Box<Error>)
Failed to load manifest from workspace
- Code:
binstall::load_manifest_from_workspace - Exit: 99
CargoInstallDoesNotSupportInstallPath
cargo-install does not support --install-path
- Code:
binstall::cargo_install_does_not_support_install_path - Exit: 100
CrateContext(Box<CrateContextError>)
A wrapped error providing the context of which crate the error is about.
Errors(CrateErrors)
A wrapped error for failures of multiple crates when --continue-on-failure is specified.
Implementations
Sourceimpl BinstallError
impl BinstallError
Sourcepub fn exit_code(&self) -> ExitCode
pub fn exit_code(&self) -> ExitCode
The recommended exit code for this error.
This will never output:
- 0 (success)
- 1 and 2 (catchall and shell)
- 16 (binstall errors not handled here)
- 64 (generic error)
Sourcepub fn crate_context(self, crate_name: impl Into<CompactString>) -> Self
pub fn crate_context(self, crate_name: impl Into<CompactString>) -> Self
Add crate context to the error
pub fn crate_errors(errors: Vec<Box<CrateContextError>>) -> Option<Self>
pub fn get_report(self) -> Option<Report>